@@ -546,7 +546,10 @@ class ReturnProgress(ComplexModel):
     def __init__(self, percent=0, short_message=None, long_message=None,
                  control=None):
         super().__init__()
-        self.percent = percent
+        try:
+            self.percent = int(percent)
+        except ValueError:
+            self.percent = int(float(percent))
         self.short_message = short_message
         self.long_message = long_message
         self.control = control
